;===============================================================================
; Function Name:    _PathSplit1()
; Description:      Split the path to 8 elements.
; Parameter(s):     $sPath - Path to split.
; Requirement(s):   AutoIt 3.2.2.0.
; Return Value(s):  On seccess - Array $RetArray that contain 8 elements:
;               $RetArray[0] = Full path ($sPath)
;               $RetArray[1] = Drive letter
;               $RetArray[2] = Path without FileName and extension
;               $RetArray[3] = Full path without File Extension
;               $RetArray[4] = Full path without drive letter
;               $RetArray[5] = FileName and extension
;               $RetArray[6] = Just Filename
;               $RetArray[7] = Just Extension of a file
;
;               On failure - If $sPath not include correct path (the path is not splitable),
;               then $sPath returned.
;               If $sPath not include needed delimiters, or it's emty,
;               then @error set to 1, and returned -1.
;
; Note(s):      The path can include backslash as well (exmp: C:/test/test.zip).
;
; Author(s):        G.Sandler a.k.a CreatoR (MsCreatoR) - Thanks to amel27 for help with RegExp
;===============================================================================
Func _PathSplitExt($sPath)
	If $sPath = "" Or StringRegExp($sPath, ('.*\\.*\/')) Then Return SetError(1, 0, -1)
	Local $RetArray[8], $pDelim = ""
	If StringRegExp($sPath, '^(?i)([A-Z]:|\\)(\\[^\\]+)+$') Then $pDelim = "\"
	If StringRegExp($sPath, '(?i)(^.*:/)(/[^/]+)+$') Then $pDelim = "//"
	If $pDelim = "" Then $pDelim = "/"
	If Not StringInStr($sPath, $pDelim) Then Return $sPath
	If $pDelim = "\" Then $pDelim &= "\"
	$RetArray[0] = $sPath
	$RetArray[1] = StringRegExpReplace($sPath, $pDelim & '.*', $pDelim)
	$RetArray[2] = StringRegExpReplace($sPath, $pDelim & '[^' & $pDelim & ']*$', '')
	$RetArray[3] = StringRegExpReplace($sPath, '\.[^.]*$', '')
	$RetArray[4] = StringRegExpReplace($sPath, '(?i)([A-Z]:' & $pDelim & ')', '')
	$RetArray[5] = StringRegExpReplace($sPath, '^.*' & $pDelim, '')
	$RetArray[6] = StringRegExpReplace($RetArray[5], '\.[^.]*$', '')
	$RetArray[7] = StringRegExpReplace($sPath, '^.*\.', '')
	Return $RetArray
EndFunc   ;==>_PathSplit1